
body {
    background: linear-gradient(0deg, #49a09d, #5f2c82);
    font-family: sans-serif;
}

table {
    border-collapse: collapse;
    overflow: hidden;
    box-shadow: 0 0 20px rgba(0,0,0,0.1);
    margin-right: auto;
    margin-left: auto;
}

h1 {
    color: white;
    text-align: center;
}

caption {
    color: white;
    padding-top: 0.75rem;
}

th,
td {
    padding: 15px;
    background-color: rgba(255,255,255,0.2);
    color: #fff;
    text-align: center;
}

th {
    background-color: #55608f;
}
